/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.uinfo.salix;

import java.util.Collection;

import org.dive4elements.river.artifacts.common.ExportContextCSV;
import org.dive4elements.river.artifacts.common.ResultRow;

/**
 * @author Domenico Nardi Tironi
 */
final class SalixLineCalculationHistoricalResult extends SalixLineCalculationResult {

    private static final long serialVersionUID = 1L;

    private final String timeString;

    public SalixLineCalculationHistoricalResult(final String label, final String[] scenarioLabels, final String partialRangeString, final String timeString,
            final Collection<ResultRow> rows) {

        super(label, scenarioLabels, partialRangeString, "", rows);
        this.timeString = timeString;
    }


    @Override
    protected void writeCSVResultMetadata(final ExportContextCSV exportContextCSV) {
        writeHistoricalViewCSVMetadata(exportContextCSV);
        exportContextCSV.writeBlankLine();
    }

    private void writeHistoricalViewCSVMetadata(final ExportContextCSV exportContextCSV) {

        final String main = "uinfo.export.csv.meta.header.salix";
        final String mainSub = "uinfo.export.csv.meta.header.salix.historical";

        // "##Historische Betrachtung"
        exportContextCSV.writeCSVMetaEntry(mainSub);

        // "# Teilabschnitt: "
        exportContextCSV.writeCSVMetaEntry(main + ".teilabschnitt", this.getPartialRangeString());

        // "# Historischer Zeitpunkt: "
        exportContextCSV.writeCSVMetaEntry(mainSub + ".zeitpunkt", this.timeString);

        exportContextCSV.writeBlankLine();
    }
}